from django.db import models
from django.core.validators import MaxValueValidator, MinValueValidator, MaxLengthValidator, MinLengthValidator
from django.urls import reverse

# Create your models here.
class Author(models.Model):
    first_name=models.CharField(max_length=100)
    last_name=models.CharField(max_length=100)
    age=models.IntegerField(
        validators =[MinValueValidator(1)]
    )
    nationality=models.CharField(max_length=100)
    bio=models.CharField(max_length=700, null=True)
    
    def __str__(self):
        return'{} {}'.format(self.first_name, self.last_name)
    
    def get_absolute_url(self):
        return reverse("Author_details", kwargs={"pk": self.pk})
    
class Book(models.Model):
    title=models.CharField(max_length=100)
    author=models.ForeignKey(
        Author,
        on_delete=models.CASCADE
    )
    publisher=models.CharField(max_length=100)
    year_published=models.DateField()
    ISBN=models.BigIntegerField(
        validators =[MinValueValidator(1000000000000), MaxValueValidator(9999999999999)]
    )
    blurb=models.TextField(
        validators =[
            MinLengthValidator(100),
            MaxLengthValidator(200)
        ]
    )
    
    def __str__(self):
        return'{}'.format(self.title)
    
    def get_absolute_url(self):
        return reverse("Book_details", kwargs={'pk': self.pk})